Hoy!
====

A dead simple notifier.


Installation
------------

```bash
pipx install hoy
```


Usage
-----

Simply run `hoy` after a long-running process (example: `sleep 5`):

```bash
sleep 5; hoy
```

Or if you want different messages for success and failure:

```bash
sleep 5 && hoy Success! || hoy Fail!
```
